@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 
-from .config import DataConfig, file_read_bytes, file_write_bytes, file_write_text, file_move, file_delete
+from .config import DataConfig, file_read_bytes, file_write_bytes, file_write_text, file_move, file_delete, KeyPtr
 from .cryptography import SaltHandle, CryptHandle
 from .create_key import create_key
 
@@ -9,5 +9,5 @@ __version__ = '1.0.0'
 __all__ = [
     "DataConfig", "CryptHandle", "SaltHandle",
     "create_key", "file_read_bytes", "file_write_bytes", "file_write_text", "file_move",
-    "file_delete",
+    "file_delete", "KeyPtr"
 ]
\ No newline at end of file
