@@ -58,9 +58,12 @@ class LogHandle(object):
         for handler in logging.root.handlers[:]:
             logging.root.removeHandler(handler)
 
-    def gui_console(self):
-        if self.__gui_console:
+    def gui_console(self, destroy=False, turn_off=False):
+        if self.__gui_console and destroy:
             self.__gui_console.destroy()
+            self.__gui_console = None
+        elif self.__gui_console and turn_off:
+            self.__gui_console = None
         else:
             self.__gui_console = GUIConsole()
 
@@ -105,8 +108,10 @@ class LogHandle(object):
         logging.shutdown()
 
 
-class GUIConsole(Toplevel, Thread):
-    __console_frame = None
+class GUIConsole(Toplevel):
+    __print_lock = Lock()
+    __print_queue = list()
+    __console_text = None
 
     """
         Class to show logging in a GUI window by using Toplevel in tkinter
@@ -114,24 +119,29 @@ class GUIConsole(Toplevel, Thread):
 
     def __init__(self):
         Toplevel.__init__(self)
-        Thread.__init__(self)
+        self.__build()
+        self.__start_idle()
 
-        self.__print_queue = list()
-        self.__print_lock = Lock()
+    def __start_idle(self):
+        self.after(5, self.__on_idle)
 
-    def run(self):
-        self.__console_frame = Frame(self)
-        self.__console_frame.after(5, self.__on_idle)
+    def print_gui(self, msg, sep='\n'):
+        with self.__print_lock:
+            self.__print_queue.append(str(msg) + sep)
+
+    def __build(self):
+        my_frame = Frame(self)
+        my_frame.pack()
+
+        self.__console_text = Text(my_frame, bg="black", fg="white")
+        self.__console_text.pack()
 
     def __on_idle(self):
         with self.__print_lock:
             for msg in self.__print_queue:
-                self.__console_frame.text.insert(END, msg)
-                self.__console_frame.text.see(END)
+                self.__console_text.insert(END, msg)
+                self.__console_text.see(END)
 
             self.__print_queue = []
-        self.__console_frame.after(5, __on_idle)
 
-    def print_gui(self, msg, sep="\n"):
-        with self.__print_lock:
-            self.__print_queue.append(str(msg) + sep)
+        self.after(5, self.__on_idle)
